Module util

Module util 

Utility modules for the Zmanim API.

Modules

geolocation
Geolocation struct, with some math for local mean time
noaa_calculator
Implementation of sunrise and sunset functions to calculate astronomical times based on the NOAA algorithm.
zenith_adjustments
Basic calculations used for sun-time algorithms (though currently only the NOAA algorithm is available).